<?php
/**
 * Plugin Name: TweetView-Widget
 * Plugin URI: http://blog.ppfeufer.de/tweetview-widget-anzeige-der-letzten-tweets-in-der-wordpress-sidebar/
 * Description: Adds a widget to your blogs sidebar to show your latest tweets. (XHTML-valid - based on Tweetbox from Rob Carr)
 * Version: 1.3.1
 * Author: <a href="http://sharjes.de">Simon Harjes</a> & <a href="http://ppfeufer.de">H.-Peter Pfeufer</a>
 */

/**
 * Changelog:
 * = 1.3.1 (05. 12. 2010) =
 * Add: Support via Flattr :-)
 *
 * = 1.3.0 (05. 12. 2010) =
 * Update: Now Using WordPress Widget-API
 * Fix: Major code cleanup
 * Test: Ready for WordPress 3.1 (tested on WordPress 3.1-beta1-16723.)
 *
 * = 1.2.4 =
 * Code cleanup
 *
 * = 1.2.3 =
 * Upload to Wordpress Plugindirectory
 *
 * = 1.2.2 =
 * Fixed a little bug in JavaScript
 *
 * = 1.2.1 =
 * Added lnk to own twitterprofile unter the tweets
 *
 * = 1.2.0 =
 * JavaScript no longer as inline. Now in external file.
 *
 * = 1.1.2 =
 * Little Bugfix in #hashtag function
 *
 * = 1.1.0 =
 * #Hashtags are now linked
 *
 * = 1.0.0 =
 * Initial Release
 */

if(!is_admin()) {
	define('TWEETVIEW_VERSION', '1.3.1');

	$js_url = plugins_url(basename(dirname(__FILE__)) . '/js/tweetview.js');

	/**
	 * jQuery einbinden
	 * Diese werden ab Wordpress-Version 3.0 von Wordpress selbst zur Verfügung gestellt.
	 * Sollte das Plugin "Use Google Libraries" installiert sein, werden die aktuellen Versionen von Google CDN verwendet.
	 */
	wp_enqueue_script('jquery');

	/**
	 * JavaScript in Wordpress einbinden
	 */
	wp_register_script('tweetview-js', $js_url, false, TWEETVIEW_VERSION, true);
	wp_enqueue_script('tweetview-js');
}

class Tweetview_Widget extends WP_Widget {
	function Tweetview_Widget() {
		if(function_exists('load_plugin_textdomain')) {
			load_plugin_textdomain('tweetview-sidebar-widget', PLUGINDIR . '/' . dirname(plugin_basename(__FILE__)) . '/languages', dirname(plugin_basename(__FILE__)) . '/languages');
		}

		$widget_ops = array(
			'classname' => 'tweetview_widget',
			'description' => __('Tweetview Widget', 'tweetview-sidebar-widget')
		);

		$control_ops = array();

		$this->WP_Widget('tweetview_widget', 'Tweetview Widget', $widget_ops, $control_ops);
	}

	function form($instance) {
		$instance = wp_parse_args((array) $instance, array(
			'tweetview_title' => '',
			'tweetview_username' => '',
			'tweetview_no_tweets' => '5'
		));

		echo '
				<script type="text/javascript">
				/* <![CDATA[ */
					(function() {
						var s = document.createElement(\'script\'), t = document.getElementsByTagName(\'script\')[0];
						s.type = \'text/javascript\';
						s.async = true;
						s.src = \'http://api.flattr.com/js/0.6/load.js?mode=auto\';
						t.parentNode.insertBefore(s, t);
					})();
				/* ]]> */
				</script>';

		echo '<p><label>Titel<br /></label><input id="' . $this->get_field_id('tweetview_title') . '" name="' . $this->get_field_name('tweetview_title') . '" type="text" value="' . $instance['tweetview_title'] . '" /></p>';
		echo '<p><label>Twitternutzer<br /><input id="' . $this->get_field_id('tweetview_username') . '" name="' . $this->get_field_name('tweetview_username') . '" type="text" value="' . $instance['tweetview_username'] . '" /></p>';
		echo '<p><label>Anzahl der Tweets<br /></label><input id="' . $this->get_field_id('tweetview_no_tweets') . '" name="' . $this->get_field_name('tweetview_no_tweets') . '" type="text" value="' . $instance['tweetview_no_tweets'] . '" /></p>';
		echo '<p>You like this Plugin? Support me.<br /><a class="FlattrButton" style="display:none;" rev="flattr;button:compact;" href="http://blog.ppfeufer.de/tweetview-widget-anzeige-der-letzten-tweets-in-der-wordpress-sidebar/"></a></p>';
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;

		$new_instance = wp_parse_args((array) $new_instance, array(
			'tweetview_title' => '',
			'tweetview_username' => '',
			'tweetview_no_tweets' => '5'
		));

		$instance['tweetview_title'] = strip_tags($new_instance['tweetview_title']);
		$instance['tweetview_username'] = strip_tags($new_instance['tweetview_username']);
		$instance['tweetview_no_tweets'] = strip_tags($new_instance['tweetview_no_tweets']);

		print_r($instance);

		return $instance;
	}

	function widget($args, $instance) {
		extract($args);

		echo $before_widget;

		$title = (empty($instance['tweetview_title'])) ? '&nbsp;' : apply_filters('widget_title', $instance['tweetview_title']);

		if(!empty($title)) {
			echo $before_title . $title . $after_title;
		}

		echo $this->tweetview_output($instance, 'widget');
		echo $after_widget;
	}

	function tweetview_output($args = array(), $position) {
		echo '<script type="text/javascript">jQuery(document).ready(function() {twitter.load("' . $args['tweetview_username'] . '", ' . $args['tweetview_no_tweets'] . ')});</script>';
		echo '<ul id="tweetview_tweetlist"><li>Lade tweets ...</li></ul>';
		echo '<ul><li>Folge <a href="http://twitter.com/' . $args['tweetview_username'] . '">@' . $args['tweetview_username'] . '</a> auf Twitter.</li></ul>';
	}
}

add_action('widgets_init', create_function('', 'return register_widget("Tweetview_Widget");'));
?>